-- buff总览界面
checkRequire("Lua_BuffVo");
checkRequire("Lua_MonsterConfigData");
Lua_FightOverallBuffWindow = class("Lua_FightOverallBuffWindow", Lua_Window)
function Lua_FightOverallBuffWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_FightOverallBuffWindow";
	self.skinName = "FightOverallBuffWindow_skin"
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_FightOverallBuffWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.attackerList = Lua_DragList.new(self.listObject, 323, 650, Lua_AxisDefine.Vertical);
	self.attackerList:setLocation(-162, 40, 0);
	self.attackerList.canDrag = false;
	self.attackerList:setListCell(Lua_FightBuffInfoItem, 323, 130, 1);

	self.defenderList = Lua_DragList.new(self.listObject, 323, 650, Lua_AxisDefine.Vertical);
	self.defenderList:setLocation(162, 40, 0);
	self.defenderList.canDrag = false;
	self.defenderList:setListCell(Lua_FightBuffInfoItem, 323, 130, 1);

	self:addLuaEvent("refresh_fight_buff", self, self.updateShowInfo);
end

function Lua_FightOverallBuffWindow:dispose()
	if self.attackerList ~= nil then
		self.attackerList:dispose();
		self.attackerList = nil;
	end
	if self.defenderList ~= nil then
		self.defenderList:dispose();
		self.defenderList = nil;
	end
	self:superCall("dispose");
end

function Lua_FightOverallBuffWindow:showWin(param)
	self:superCall("showWin", param);
	if param == nil then
		self:hide();
		return;
	end

	local recordVo = DataCenter.fightData:getRecordVoById(param);
	if recordVo == nil then
		self:hide();
		return;
	end

	if self.recordId ~= param then
		self.recordId = param;

		if recordVo.attacker == nil or tonumber(recordVo.attacker.id) <= 0 then
			self.attackerName.text = "";
		else
			self.attackerName.text = recordVo.attacker.name;
		end

		if recordVo.defender == nil or tonumber(recordVo.defender.id) <= 0 then
			self.defenderName.text = "";
		else
			self.defenderName.text = recordVo.defender.name;
		end

		local attackArr = Array();
		local attackList = DataCenter.thingData:getThingIdsByFormationType(param, Lua_FightDefine.FIGHT_ATTACKER);
		if attackList ~= nil then
			for i = 1, attackList:getSize() do
				local thing = DataCenter.thingData:getThingPlayer(recordVo.sceneId, param, attackList[i]);
				if thing and not thing.data.isSummoned and (thing.kind == Lua_ThingDefine.HERO or thing.kind == Lua_ThingDefine.MONSTER) then
					attackArr:add({ index = i, attacker = 1, sceneId = recordVo.sceneId, recordId = param, playerId = attackList[i] });
				end
			end
		end
		self.attackerList:setArrayData(attackArr);

		local defendArr = Array();
		local defendList = DataCenter.thingData:getThingIdsByFormationType(param, Lua_FightDefine.FIGHT_DEFENDER);
		if defendList ~= nil then
			for i = 1, defendList:getSize() do
				local thing = DataCenter.thingData:getThingPlayer(recordVo.sceneId, param, defendList[i]);
				if thing and not thing.data.isSummoned and (thing.kind == Lua_ThingDefine.HERO or thing.kind == Lua_ThingDefine.MONSTER) then
					defendArr:add({ index = i, sceneId = recordVo.sceneId, recordId = param, playerId = defendList[i] });
				end
			end
		end
		self.defenderList:setArrayData(defendArr);
	else
		self.attackerList:updateShowList();
		self.defenderList:updateShowList();
	end
end

function Lua_FightOverallBuffWindow:updateShowInfo()
	self.attackerList:updateShowList();
	self.defenderList:updateShowList();
end















Lua_FightBuffInfoItem = class("Lua_FightBuffInfoItem", Lua_ListCell);
function Lua_FightBuffInfoItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_FightBuffInfoItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemBg = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 323, 130);

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setClick(self, self.onCheckBuff);
end

function Lua_FightBuffInfoItem:dispose()
	self:clearBuffIcon();
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_FightBuffInfoItem:setData(data)
	self.data = data;
	if data.attacker == 1 then
		self.itemIcon:setLocation(-95, 0, 0);
	else
		self.itemIcon:setLocation(95, 0, 0);
	end

	if data.index % 2 == 1 then
		self.itemBg:setAltas("fight_atlas_1", "ui_zd_widget_006");
	else
		self.itemBg:setAltas("fight_atlas_1", "ui_zd_widget_007");
	end

	local thing = DataCenter.thingData:getThingPlayer(data.sceneId, data.recordId, data.playerId);
	self.thingData = thing.data;
	local heroId = tonumber(tostring(self.thingData.objId));
	if self.thingData.kind == Lua_ThingDefine.MONSTER then
		heroId = Lua_MonsterConfigData.getMonsterConfig(heroId).heroId;
	end
	local vo = Lua_HeroVo.new(heroId);
	vo.level = self.thingData.lvl;
	self.itemIcon:setData(vo);

	self:updateData();
end

function Lua_FightBuffInfoItem:updateData()
	self:returnIcon();
	if self.thingData == nil then
		return;
	end
	self.itemIcon:setGray(tonumber(tostring(self.thingData.hp)) <= 0);

	local count = self.thingData.buffCount;
	if count <= 0 then
		return;
	end

	count = count - 1;
	local dic = {};
	for i = 0, count do
		local buffId = self.thingData:getBuffIdByIdx(i);
		local buffData = Lua_BuffConfigData.getConfigData(buffId);
		if buffData ~= nil then
			local vo = Lua_BuffVo.new();
			vo.atlas = buffData.atlas;
			vo.sprite = buffData.sprite;
			vo.sortWeight = buffData.sort;
			vo.overlayNum = self.thingData:getBuffOverlayNumByIdx(i);
			if buffData.main_type == nil then
				dic[buffId] = vo;
			else
				if dic[buffData.main_type] == nil then
					dic[buffData.main_type] = vo;
				else
					dic[buffData.main_type].overlayNum = dic[buffData.main_type].overlayNum + 1;
				end
			end
		end
	end

	local arr = Array();
	for k,v in pairs(dic) do
		arr:add(v);
	end
	arr:sort("sortWeight", false);

	local icon;
	for i = 1, arr:getSize() do
		icon = self:createIcon();
		if self.data.attacker == 1 then
			icon:setLocation(-10 + ((i - 1) % 4) * 50, 20 + Mathf.Floor((i - 1) / 4) * 50 * -1, 0);
		else
			icon:setLocation(10 - ((i - 1) % 4) * 50, 20 + Mathf.Floor((i - 1) / 4) * 50 * -1, 0);
		end
		icon:setData(arr[i]);
		icon:setClick(self, self.onCheckBuff);
	end
end

function Lua_FightBuffInfoItem:clearBuffIcon()
	if self.showList ~= nil then
		self.showList:dispose();
		self.showList:clear();
		self.showList = nil;
	end
	if self.hideList ~= nil then
		self.hideList:dispose();
		self.hideList:clear();
		self.hideList = nil;
	end
end

function Lua_FightBuffInfoItem:createIcon()
	if self.showList == nil or self.hideList == nil then
		return;
	end

	local len = self.hideList:getSize();
	local icon = nil;
	if len > 0 then
		icon = self.hideList:remove();
	end

	if icon == nil then
		icon = Lua_BuffIcon.new(self.content);
	end
	icon:setEnable(true);
	self.showList:add(icon);
	return icon;
end

function Lua_FightBuffInfoItem:returnIcon()
	if self.showList == nil then
		self.showList = Array();
	end
	if self.hideList == nil then
		self.hideList = Array();
	end
	local len = self.showList:getSize();
	local icon;
	while len > 0 do
		icon = self.showList:remove(len);
		icon:setEnable(false);
		self.hideList:add(icon)
		len = len - 1;
	end
end

function Lua_FightBuffInfoItem:onCheckBuff()
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_FightBuffDetailsWindow", Lua_WinParam.ACTION_OPEN, self.data);
end