-- 战斗伤害总览
Lua_FightOverallHurtWindow = class("Lua_FightOverallHurtWindow", Lua_Window);
function Lua_FightOverallHurtWindow:ctor(p)
	self:superCall("ctor");

	self.windowName = "Lua_FightOverallHurtWindow";
	self.skinName = "FightOverallHurtWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_FightOverallHurtWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.selectTeamBg:setEnable(false);

	self.defenderAvatar = Lua_AvatarItem.new(self.content);
	self.defenderAvatar:setScale(0.7, 0.7, 1);
	self.defenderAvatar:setLocation(-267, 534.5, 0);

	self.attackerAvatar = Lua_AvatarItem.new(self.content);
	self.attackerAvatar:setScale(0.7, 0.7, 1);
	self.attackerAvatar:setLocation(-267, 14, 0);

	self:addLuaEvent("FIGHT_TEAM_SELECT", self, self.onTeamSelected);
end

function Lua_FightOverallHurtWindow:dispose()
	self:endTimer();
	if self.defenderAvatar ~= nil then
		self.defenderAvatar:dispose();
		self.defenderAvatar = nil;
	end
	if self.attackerAvatar ~= nil then
		self.attackerAvatar:dispose();
		self.attackerAvatar = nil;
	end
	if self.attackerHurtList ~= nil then
		self.attackerHurtList:dispose();
		self.attackerHurtList = nil;
	end
	if self.defenderHurtList ~= nil then
		self.defenderHurtList:dispose();
		self.defenderHurtList = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.teamArr ~= nil then
		self.teamArr:clear();
		self.teamArr = nil;
	end
	self.teamDic = nil;
	self:superCall("dispose");
end

function Lua_FightOverallHurtWindow:showWin(param)
	self:superCall("showWin", param);

	if param.selectIdx == nil then
		self.selectIdx = 1;
	    self:updateHurtInfo(param);
	else
		self.selectIdx = param.selectIdx;
		self:updateHurtInfo(param.hurtInfo);
	end
end

function Lua_FightOverallHurtWindow:updateHurtInfo(hurtInfo)
	if hurtInfo == nil then
		return;
	end

	if hurtInfo.defender == nil or tonumber(hurtInfo.defender.id) <= 0 then
		self.defenderName.text = "";
		self.defenderAvatar:setRoleDressUp(nil);
	else
		self.defenderName.text = hurtInfo.defender.name;
		self.defenderAvatar:setRoleDressUp(hurtInfo.defender.dress_info);
	end

	if hurtInfo.attacker == nil or tonumber(hurtInfo.attacker.id) <= 0 then
		self.attackerName.text = "";
		self.attackerAvatar:setRoleDressUp(nil);
	else
		self.attackerName.text = hurtInfo.attacker.name;
		self.attackerAvatar:setRoleDressUp(hurtInfo.attacker.dress_info);
	end

	local win_type = hurtInfo.win_type;
	if win_type == 1 then --1：攻方胜利
		self.defenderResultIcon:setEnable(true);
		self.defenderResultIcon:setAltas("fight_atlas_1", "ui_zd_icon_012");
		self.attackerResultIcon:setEnable(true);
		self.attackerResultIcon:setAltas("fight_atlas_1", "ui_zd_icon_011");
	elseif win_type == 2 then -- 2：守方胜利
		self.defenderResultIcon:setEnable(true);
		self.defenderResultIcon:setAltas("fight_atlas_1", "ui_zd_icon_011");
		self.attackerResultIcon:setEnable(true);
		self.attackerResultIcon:setAltas("fight_atlas_1", "ui_zd_icon_012");
	else
		self.defenderResultIcon:setEnable(false);
		self.attackerResultIcon:setEnable(false);
	end

	local list = hurtInfo.hurt_collect_list; --伤害统计列表
	if list == nil or #list <= 0 then
		return;
	end

	-- 一种是车轮战，一种是胜场战。
	-- 根据轮次分，车轮战第一轮就是双方对打，第二轮是输方第二队打胜利方剩余单位。 胜利站就是第一轮是攻一队打守一队，第二轮就是攻二队打守二队。
	self.teamArr = Array();
	self.teamDic = {};
	local obj;
	for i = 1, #list do
		obj = list[i];
		self.teamArr:add(obj.rotation);
		self.teamDic[obj.rotation] = obj;
	end

	if #list > 1 then
		self.teamArr:sortf(self, self.teamSortFun);

		if self.btnList == nil then
			self.btnList = Array();
		end
		local len = self.teamArr:getSize() - self.btnList:getSize();
		local item;

		while (len > 0) do
			item = Lua_FightHurtTeamItem.new(self.content);
			self.btnList:add(item);
			len = len - 1;
		end

		while (len < 0) do
			item = self.btnList:remove(1);
			item:dispose();
			len = len + 1;
		end

		len = self.btnList:getSize();
		local space = 173;
		local w;
		local posX;
		for i = 1, len do
			item = self.btnList[i];
			if i == 1 then
				item:setStyle(1);
			elseif i == len then
				item:setStyle(2);
			else
				item:setStyle();
			end
			item:setData(self.teamArr[i]);

			w = -(space * len) / 2 + space / 2;
			posX = ((i - 1) % len) * space + w;
			item:setLocation(posX, -527.5, 0);
		end
		self.btnList[self.selectIdx]:onPressClick();

		self.selectTeamBg:setEnable(true);
		self.selectTeamBg:SetDimensions(space * len + 13, 70);
	else
		self.selectTeamBg:setEnable(false);
		local rotation = self.teamArr[1];
		self:showHurtInfo(self.teamDic[rotation]);
	end
end

function Lua_FightOverallHurtWindow:teamSortFun(a, b)
	if a > b then
		return false;
	end
	return true;
end

function Lua_FightOverallHurtWindow:showHurtInfo(info)
	if info == nil then
		return;
	end

	local attackArr = Array();
	local defendArr = Array();
	local obj;
	local hurt;
	local cure;
	local bearHurt;
	local num;
	local maxHurt = -1;
	local maxCure = -1;
	local maxBearHurt = -1;
	local maxNum = -1;
	local maxIdx = -1;

	local list = info.attacker_hurt_collect;
	if list ~= nil then
		for i = 1, #list do
			obj = list[i];
			hurt = tonumber(obj.hurt);
			cure = tonumber(obj.cure);
			bearHurt = tonumber(obj.bear_hurt);
			num = Mathf.Abs(hurt) + Mathf.Abs(cure) + Mathf.Abs(bearHurt);
			if maxHurt < hurt then
				maxHurt = hurt;
			end
			if maxCure < cure then
				maxCure = cure;
			end
			if maxBearHurt < bearHurt then
				maxBearHurt = bearHurt;
			end
			if obj.type ~= 2 and obj.type ~= 3 and maxNum < num then
				maxNum = num;
				maxIdx = i;
			end
		end

		for i = 1, #list do
			attackArr:add({ teamType = Lua_FightDefine.FIGHT_ATTACKER, isMvp = maxIdx == i, maxHurt = maxHurt, maxCure = maxCure, maxBearHurt = maxBearHurt, info = list[i] });
		end
	end

	maxShuchu = -1;
	maxZhiliao = -1;
	maxChengshang = -1;
	maxNum = -1;
	maxIdx = -1;
	list = info.defender_hurt_collect;
	if list ~= nil then
		for i = 1, #list do
			obj = list[i];
			hurt = tonumber(obj.hurt);
			cure = tonumber(obj.cure);
			bearHurt = tonumber(obj.bear_hurt);
			num = Mathf.Abs(hurt) + Mathf.Abs(cure) + Mathf.Abs(bearHurt);
			if maxHurt < hurt then
				maxHurt = hurt;
			end
			if maxCure < cure then
				maxCure = cure;
			end
			if maxBearHurt < bearHurt then
				maxBearHurt = bearHurt;
			end
			if obj.type ~= 2 and obj.type ~= 3 and maxNum < num then
				maxNum = num;
				maxIdx = i;
			end
		end

		for i = 1, #list do
			defendArr:add({ teamType = Lua_FightDefine.FIGHT_DEFENDER, isMvp = maxIdx == i, maxHurt = maxHurt, maxCure = maxCure, maxBearHurt = maxBearHurt, info = list[i] });
		end
	end

	if self.defenderHurtList == nil then
		self.defenderHurtList = Lua_DragList.new(self.content, 653, 390, Lua_AxisDefine.Vertical);
		self.defenderHurtList:setLocation(0, 256, 0);
		self.defenderHurtList:setListCell(Lua_FightHurtInfoItem, 653, 78, 1);
	end
	self.defenderHurtList:setArrayData(defendArr);
	self.defenderHurtList:moveToIndex(1, true);

	if self.attackerHurtList == nil then
		self.attackerHurtList = Lua_DragList.new(self.content, 653, 390, Lua_AxisDefine.Vertical);
		self.attackerHurtList:setLocation(0, -265, 0);
		self.attackerHurtList:setListCell(Lua_FightHurtInfoItem, 653, 78, 1);
	end
	self.attackerHurtList:setArrayData(attackArr);
	self.attackerHurtList:moveToIndex(1, true);

	self:startTimer();
end

function Lua_FightOverallHurtWindow:startTimer()
    if self.bTimer ~= true then
        self.bTimer = true;
        self.attackerHurtList.canDrag = false;
        self.defenderHurtList.canDrag = false;
        Lua_CommonUtil.addTimer("Lua_FightOverallHurtWindow", 0.02, self, self.onUpdateRate, nil, -1);
    end
end

function Lua_FightOverallHurtWindow:endTimer()
    if self.bTimer == true then
        self.bTimer = false;
        self.attackerHurtList.canDrag = true;
        self.defenderHurtList.canDrag = true;
        Lua_CommonUtil.removeTimer(self, self.onUpdateRate);
    end
end

function Lua_FightOverallHurtWindow:onUpdateRate()
	local arr;
	local len;
	local idx = 0;
	local bUpdateComplete = true;

	if self.attackerHurtList ~= nil then
		idx = 0;
		arr = self.attackerHurtList.showList;
		len = arr:getSize();
		for i = 1, len do
			if arr[i]:updateRate() == true then
				idx = idx + 1;
			end
		end

		if idx < len then
			bUpdateComplete = false;
		end
	end

	if self.defenderHurtList ~= nil then
		arr = self.defenderHurtList.showList;
		len = arr:getSize();
		for i = 1, len do
			if arr[i]:updateRate() == true then
				idx = idx + 1;
			end
		end

		if idx < len then
			bUpdateComplete = false;
		end
	end

	if bUpdateComplete == true then
		self:endTimer();
	end
end

function Lua_FightOverallHurtWindow:onTeamSelected(rotation)
	if self.teamArr == nil or self.teamDic == nil or self.selectedTeam == rotation then
		return;
	end
	self.selectedTeam = rotation;

	self:initList();
	self:showHurtInfo(self.teamDic[rotation]);
	for i = 1, self.btnList:getSize() do
		self.btnList[i]:setSelected(rotation);
	end
end

function Lua_FightOverallHurtWindow:initList()
	local arr;

	if self.attackerHurtList ~= nil then
		arr = self.attackerHurtList.showList;
		for i = 1, arr:getSize() do
			arr[i]:init();
		end

		arr = self.attackerHurtList.hideList;
		for i = 1, arr:getSize() do
			arr[i]:init();
		end
	end

	if self.defenderHurtList ~= nil then
		arr = self.defenderHurtList.showList;
		for i = 1, arr:getSize() do
			arr[i]:init();
		end

		arr = self.defenderHurtList.hideList;
		for i = 1, arr:getSize() do
			arr[i]:init();
		end
	end
end





















Lua_FightHurtTeamItem = class("Lua_FightHurtTeamItem", Lua_DisplayObject);
function Lua_FightHurtTeamItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_FightHurtTeamItem:buildShowItem()
	self:superCall("buildShowItem");

	self.btnImg = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0);
	self.btnImg:addClickFuntion(self, self.onPressClick);

	self.btnText = UICreate.createLabel(self.content, nil, 0, 0, 100, 40, 30);
	self.btnText.pivot = UIUtils.Pivot.Center;
	self.btnText.fontName = Lua_MyUISettings.huakangFontName;
	self.btnText.alignmentValue = 4;
	self.btnText.horizontalOverflowValue = 1;
	self.btnText.colorStr = Lua_ColorDefine.transColor("DEDFE0");
end

function Lua_FightHurtTeamItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_FightHurtTeamItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
	self.btnText.text = LanUtil.formateStr(302005, convert_arab_to_chinese(data));
end

function Lua_FightHurtTeamItem:setStyle(style)
	self.style = style;
	if style == 1 then
		self.btnImg:setAltas("common_altas_1", "ui_common_button_040_n");
		self.btnImg:setScale(1, 1, 1);
	elseif style == 2 then
		self.btnImg:setAltas("common_altas_1", "ui_common_button_040_n");
		self.btnImg:setScale(-1, 1, 1);
	else
		self.btnImg:setAltas("common_altas_1", "ui_common_button_041_n");
		self.btnImg:setScale(1, 1, 1);
	end
end

function Lua_FightHurtTeamItem:setSelected(data)
	if self.data == data then
		if self.style == 1 then
			self.btnImg:setAltas("common_altas_1", "ui_common_button_040_p");
			self.btnImg:setScale(1, 1, 1);
		elseif self.style == 2 then
			self.btnImg:setAltas("common_altas_1", "ui_common_button_040_p");
			self.btnImg:setScale(-1, 1, 1);
		else
			self.btnImg:setAltas("common_altas_1", "ui_common_button_041_p");
			self.btnImg:setScale(1, 1, 1);
		end
		self.btnText.colorStr = Lua_ColorDefine.transColor("8B5E34");
	else
		if self.style == 1 then
			self.btnImg:setAltas("common_altas_1", "ui_common_button_040_n");
			self.btnImg:setScale(1, 1, 1);
		elseif self.style == 2 then
			self.btnImg:setAltas("common_altas_1", "ui_common_button_040_n");
			self.btnImg:setScale(-1, 1, 1);
		else
			self.btnImg:setAltas("common_altas_1", "ui_common_button_041_n");
			self.btnImg:setScale(1, 1, 1);
		end
		self.btnText.colorStr = Lua_ColorDefine.transColor("DEDFE0");
	end
end

function Lua_FightHurtTeamItem:onPressClick(go)
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("FIGHT_TEAM_SELECT", self.data);
end



















-- 伤害列表item
Lua_FightHurtInfoItem = class("Lua_FightHurtInfoItem", Lua_ListCell);
function Lua_FightHurtInfoItem:ctor(p)
	self:superCall("ctor", p, "FightHurtInfoItem_skin", false);
end

function Lua_FightHurtInfoItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bar_1.typeValue = 3;
	self.bar_1.fillMethodValue = 0;
	self.bar_1.fillOrigin = 0;
	self.bar_2.typeValue = 3;
	self.bar_2.fillMethodValue = 0;
	self.bar_2.fillOrigin = 0;
	self.bar_3.typeValue = 3;
	self.bar_3.fillMethodValue = 0;
	self.bar_3.fillOrigin = 0;

	self:init();

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.64, 0.64);
	self.itemIcon:setLocation(-270, 0, 0);
end

function Lua_FightHurtInfoItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_FightHurtInfoItem:init()
	self.bTweenCompleted = false;

	self.startHurtValue = 0;
	self.targetHurtVal = 0;
	self.maxHurtValue = 1;

	self.startCureValue = 0;
	self.targetCureVal = 0;
	self.maxCureValue = 1;

	self.startBearValue = 0;
	self.targetBearVal = 0;
	self.maxBearValue = 1;
end

function Lua_FightHurtInfoItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	if data.teamType == Lua_FightDefine.FIGHT_ATTACKER then
		self.itemBg:setAltas("fight_atlas_1", "ui_zd_widget_013");
	else
		self.itemBg:setAltas("fight_atlas_1", "ui_zd_widget_012");
	end

	self:updateData();
	self:updateAvatar();
end

function Lua_FightHurtInfoItem:updateData()
	if self.data ~= nil then
		self.startHurtValue = 0;
		self.targetHurtVal = tonumber(self.data.info.hurt);
		self.maxHurtValue = self.data.maxHurt;
		self.value_1.text = numberTrans(self.targetHurtVal);
		self.bar_1:setMaxValue(self.maxHurtValue);

		if self.bTweenCompleted == false then
			self.bar_1:setValue(0);
		else
			self.bar_1:setValue(self.targetHurtVal);
		end

		self.startCureValue = 0;
		self.targetCureVal = tonumber(self.data.info.cure);
		self.maxCureValue = self.data.maxCure;
		self.value_2.text = numberTrans(self.targetCureVal);
		self.bar_2:setMaxValue(self.maxCureValue);

		if self.bTweenCompleted == false then
			self.bar_2:setValue(0);
		else
			self.bar_2:setValue(self.targetCureVal);
		end

		self.startBearValue = 0;
		self.targetBearVal = tonumber(self.data.info.bear_hurt);
		self.maxBearValue = self.data.maxBearHurt;
		self.value_3.text = numberTrans(self.targetBearVal);
		self.bar_3:setMaxValue(self.maxBearValue);
		
		if self.bTweenCompleted == false then
			self.bar_3:setValue(0);
		else
			self.bar_3:setValue(self.targetBearVal);
		end
	end
end

-- 更新头像
function Lua_FightHurtInfoItem:updateAvatar()
    if self.data ~= nil and self.data.info ~= nil then
		local heroId = tonumber(tostring(self.data.info.sort_id));
		local pType = self.data.info.type;
		if pType == 0 then -- 英雄
			self.itemIcon:setEnable(true);
		elseif pType == 1 then --怪物
			self.itemIcon:setEnable(true);
			heroId = Lua_MonsterConfigData.getMonsterConfig(heroId).heroId;
		elseif pType == 2 then --boss
			self.itemIcon:setEnable(true);
			heroId = Lua_MonsterConfigData.getMonsterConfig(heroId).heroId;
		else--if pType == 3 then --主角
			self.itemIcon:setEnable(false);
			heroId = nil;
		end

		if heroId ~= nil then
			local vo = Lua_HeroVo.new(heroId);
			vo.level = self.data.info.level;
			vo.star = self.data.info.star;
			self.itemIcon:setData(vo);
		end
	end
end

function Lua_FightHurtInfoItem:updateRate()
	local isComplete = true;
	if self.targetHurtVal > 0 then
		if self.startHurtValue < self.targetHurtVal then
			self.startHurtValue = self.startHurtValue + (self.maxHurtValue / 30);
			if self.startHurtValue > self.targetHurtVal then
				self.startHurtValue = self.targetHurtVal;
			else
				isComplete = false;
			end
			self.bar_1:setValue(self.startHurtValue);
		end
	end

	if self.targetCureVal > 0 then
		if self.startCureValue < self.targetCureVal then
			self.startCureValue = self.startCureValue + (self.maxHurtValue / 30);
			if self.startCureValue > self.targetCureVal then
				self.startCureValue = self.targetCureVal;
			else
				isComplete = false;
			end
			self.bar_2:setValue(self.startCureValue);
		end
	end 

	if self.targetBearVal > 0 then
		if self.startBearValue < self.targetBearVal then
			self.startBearValue = self.startBearValue + (self.maxBearValue / 30);
			if self.startBearValue > self.targetBearVal then
				self.startBearValue = self.targetBearVal;
			else
				isComplete = false;
			end
			self.bar_3:setValue(self.startBearValue);
		end
	end 

	self.bTweenCompleted = isComplete;
	return isComplete;
end