Lua_FightTeamPanel = class("Lua_FightTeamPanel", Lua_DisplayObject);
function Lua_FightTeamPanel:ctor(p)
    self:superCall("ctor", p);
end

function Lua_FightTeamPanel:buildShowItem()
    self:superCall("buildShowItem");

	self.prompt = UICreate.createLabel(self.content, nil, 0, 0, 100, 40, 30);
	self.prompt.pivot = UIUtils.Pivot.Center;
	self.prompt.fontName = Lua_MyUISettings.fangzhengFontName;
	self.prompt.alignmentValue = 5;
	self.prompt.horizontalOverflowValue = 1;

    self.leftItem = Lua_FightTeamItem.new(self.content);
    self.leftItem:setLocation(-240, 0, 0);

	self.rightItem = Lua_FightTeamItem.new(self.content);
	self.rightItem:setLocation(240, 0, 0);
end

function Lua_FightTeamPanel:dispose()
    self:superCall("dispose");
end

function Lua_FightTeamPanel:setData(recordId, teamId)
	self.teamId = teamId;
	if self.recordId ~= recordId then
		self:updateData(recordId);
	end
    self.recordId = recordId;
end

function Lua_FightTeamPanel:updateData(recordId)
	local recordVo = DataCenter.fightData:getRecordVoById(recordId);
	if recordVo == nil or recordVo.ownType == -1 then
		self.prompt.text = "观战中";
	else
		self.prompt.text = "";
	end
	
	local arr = DataCenter.fightData:getTeamArrById(self.teamId);
	if arr == nil then
		return;
	end

	local index = 0;
	for i = 1, arr:getSize() do
		if arr[i] ~= recordId then
			index = index + 1;
			if index == 1 then
				self.leftItem:setData(arr[i]);
			elseif index == 2 then
				self.rightItem:setData(arr[i]);
			end
		end
	end
end

function Lua_FightTeamPanel:updateHp()
	self.leftItem:updateHp();
	self.rightItem:updateHp();
end




















Lua_FightTeamItem = class("Lua_FightTeamItem", Lua_DisplayObject);
function Lua_FightTeamItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_FightTeamItem:buildShowItem()
	self:superCall("buildShowItem");

	self.bg = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_edit_001", 0, 0, 250, 150);
	self.bg:addClickFuntion(self, self.onClick);

	self.attackerAvatar = Lua_AvatarItem.new(self.content);
	self.attackerAvatar:setLocation(-60, 0, 0);
	self.attackerAvatar:setScale(0.8, 0.8, 0.8);
	self.attackerAvatar:setRoleAvatar(0);
	self.attackerAvatar:setRoleFrame(0);

	self.bossAvatar = Lua_ItemIcon.new(self.content);
	self.bossAvatar:setLocation(60, 0, 0);
	self.bossAvatar:setScale(0.8, 0.8, 0.8);

    self.attackerBar = UICreate.createProgressBar(self.content, "common_altas_1", "ui_common_progress_001_b", "common_altas_1", "ui_common_progress_001_f", 0, 0, 100, 15);
    self.attackerBar:setLocation(-60, -60, 0);

    self.bossBar = UICreate.createProgressBar(self.content, "common_altas_1", "ui_common_progress_001_b", "common_altas_1", "ui_common_progress_001_f", 0, 0, 100, 15);
    self.bossBar:setLocation(60, -60, 0);
end

function Lua_FightTeamItem:dispose()
	if self.attackerAvatar ~= nil then
		self.attackerAvatar:dispose();
		self.attackerAvatar = nil;
	end
	if self.bossAvatar ~= nil then
		self.bossAvatar:dispose();
		self.bossAvatar = nil;
	end
	self.recordVo = nil;
    self:superCall("dispose");
end

function Lua_FightTeamItem:setData(recordId)
	if self.recordId == recordId then
		return;
	end
	self.recordId = recordId;

	self.recordVo = DataCenter.fightData:getRecordVoById(recordId);
	if self.recordVo == nil then
		return;
	end

	local attacker = self.recordVo.attacker;
	self.attackerAvatar:setRoleDressUp(attacker.dress_info);
	self.attackerAvatar:setRoleName(attacker.name);

	local arr = self.recordVo:getFighterArr(Lua_FightDefine.FIGHT_DEFENDER, 2);
	if arr ~= nil and arr:getSize() > 0 then
		local boosId = self.recordVo:getFighterInfo(arr[1]);
		local config = Lua_MonsterConfigData.getMonsterConfig(boosId);
		self.bossAvatar:setData(config.heroVo);
	end
	
	self:updateHp();
end

function Lua_FightTeamItem:updateHp()
	if self.recordVo == nil then
		return;
	end

	local maxHp = self.recordVo.attackerMaxHp;
	local hp = self.recordVo.attackerHp;
	maxHp = maxHp == nil and 1 or maxHp;
	hp = hp == nil and 1 or hp;
    self.attackerBar:setMaxValue(maxHp);
    self.attackerBar:setValue(hp);

	maxHp = self.recordVo.defenderMaxHp;
	hp = self.recordVo.defenderHp;
	maxHp = maxHp == nil and 1 or maxHp;
	hp = hp == nil and 1 or hp;
    self.bossBar:setMaxValue(maxHp);
    self.bossBar:setValue(hp);
end

function Lua_FightTeamItem:onClick(go)
	local player = DataCenter.fightData:getFightPlayerById(self.recordId);
	if player ~= nil and player.isPlayEnd == true then
		OperateAlert.show("该场战斗已结束");
		return;
	end
	DataCenter.fightData:showFightToStageByRid(self.recordId);
end