checkRequire("Lua_FightResultBaseWindow");
Lua_ArenaFightWinWindow = class("Lua_ArenaFightWinWindow", Lua_FightResultBaseWindow);
function Lua_ArenaFightWinWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ArenaFightWinWindow";
	self.skinName = "ArenaFightResultWindow_skin";
	self.winBgPath = "/images/fight/ui_jscg_widget_001.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self.openSound = "fight_win_01";

	self.bIsWin = true;
	self.bIsShowCountTime = true;
	self.bIsShowHurtBtn = true;
end

function Lua_ArenaFightWinWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.selfAvatar = Lua_AvatarItem.new(self.content);
	self.selfAvatar:setScale(0.8, 0.8, 1);
	self.selfAvatar:setLocation(-229, 88, 0);

	self.opponentAvatar = Lua_AvatarItem.new(self.content);
	self.opponentAvatar:setScale(0.8, 0.8, 1);
	self.opponentAvatar:setLocation(-229, -16, 0);
	
	self.leftIcon:setAltas("fight_atlas_1", "ui_jiesuan_line_001");
	self.rightIcon:setAltas("fight_atlas_1", "ui_jiesuan_line_001");

	if Lua_WindowUtil.isWindowShowing("Lua_ArenaWindow") then
		self.btnBack:setEnable(false);
		self.btnConfirm:setLocation(0, -452, 0);
	else
		self.btnBack:setEnable(true);
		self.btnConfirm:setLocation(-174, -452, 0);
	end
	self.btnConfirm:addClickFuntion(self, self.hide);
	self.btnBack:addClickFuntion(self, self.onBtnBackClick);
end

function Lua_ArenaFightWinWindow:dispose()
	self:clearRewardList();
	self:superCall("dispose");
end

function Lua_ArenaFightWinWindow:showWin(param)
	self:superCall("showWin", param);
	self:updateShowInfo();
	self:updateRewards(param.item_list);
end

function Lua_ArenaFightWinWindow:updateShowInfo()
	self.selfName.text = LanUtil.formateStr("<color=#FFF2C3>{1}</color>", self.showData.arena_self_info.name);
	self.selfIntegral.text = LanUtil.formateStr("<color=#FFFEE3>：{1}</color>", self.showData.arena_self_info.score);
	local score_change = self.showData.arena_self_info.score_change;
	if score_change == 0 then
		self.selfArrow:setEnable(false);
		self.selfChange.text = "";
	elseif score_change > 0 then
		self.selfArrow:setEnable(true);
		self.selfArrow:setAltas("common_altas_3", "ui_djc_label_06");
		self.selfChange.text = LanUtil.formateStr("<color=#6DFF1B>+{1}</color>", score_change);
	else
		self.selfArrow:setEnable(true);
		self.selfArrow:setAltas("common_altas_3", "ui_djc_label_05");
		self.selfChange.text = LanUtil.formateStr("<color=#FF876E>{1}</color>", score_change);
	end
	self.selfAvatar:setRoleAvatar(self.showData.arena_self_info.head_id);
	self.selfAvatar:setRoleLevel(self.showData.arena_self_info.level);

	self.opponentName.text = LanUtil.formateStr("<color=#FFF2C3>{1}</color>", self.showData.arena_fighter_info.name);
	self.opponentIntegral.text = LanUtil.formateStr("<color=#FFFEE3>：{1}</color>", self.showData.arena_fighter_info.score);
	score_change = self.showData.arena_fighter_info.score_change;
	if score_change == 0 then
		self.opponentArrow:setEnable(false);
		self.opponentChange.text = "";
	elseif score_change > 0 then
		self.opponentArrow:setEnable(true);
		self.opponentArrow:setAltas("common_altas_3", "ui_djc_label_06");
		self.opponentChange.text = LanUtil.formateStr("<color=#6DFF1B>+{1}</color>", score_change);
	else
		self.opponentArrow:setEnable(true);
		self.opponentArrow:setAltas("common_altas_3", "ui_djc_label_05");
		self.opponentChange.text = LanUtil.formateStr("<color=#FF876E>{1}</color>", score_change);
	end
	self.opponentAvatar:setRoleAvatar(self.showData.arena_fighter_info.head_id);
	self.opponentAvatar:setRoleLevel(self.showData.arena_fighter_info.level);
end

function Lua_ArenaFightWinWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self:clearRewardList();
		return;
	end

	local tab = DataCenter.packData:getRewardDic(itemList);
	local arr = DataCenter.packData:getRewardList(tab);
	if self.rewardList == nil then
		local len = arr:getSize();
		if len > 4 then
			self.rewardList = Lua_DragList.new(self.content, 540, 232.5, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 135, 152, 4);
		else
			self.rewardList = Lua_DragList.new(self.content, len * 135, 152, Lua_AxisDefine.Horizontal);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 135, 152, 1);
		end
		self.rewardList:setLocation(0, -275, 0);
	end
	self.rewardList:setArrayData(arr);
	self.rewardList.canDrag = not self.rewardList.bDragEnd;
end

function Lua_ArenaFightWinWindow:clearRewardList()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_ArenaFightWinWindow:onBtnBackClick(go)
	DataCenter.funcPathUtil:gotoFunction(1013, true, false);
end