checkRequire("Lua_FightResultBaseWindow");
Lua_ChaosForestFightWinWindow = class("Lua_ChaosForestFightWinWindow", Lua_FightResultBaseWindow);
function Lua_ChaosForestFightWinWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_ChaosForestFightWinWindow";
	self.skinName = "ChaosForestFightWinWindow_skin";
	self.openSound = "fight_win_01";
	self.winBgPath = "/images/fight/ui_jscg_widget_001.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	
	self.bIsWin = true;
	-- self.bIsShowEff = true;
	self.bIsShowCountTime = true;
	self.bIsShowHurtBtn = true;
end

function Lua_ChaosForestFightWinWindow:buildShowItem()
	self:superCall("buildShowItem");

	if Lua_WindowUtil.isWindowShowing("Lua_ChaosForestWindow") then
		self.btnBack:setEnable(false);
		self.btnSure:setLocation(0, -467, 0);
	else
		self.btnBack:setEnable(true);
		self.btnSure:setLocation(146, -467, 0);
	end
	self.btnBack:addClickFuntion(self, self.onBtnBackClick);
	self.btnSure:addClickFuntion(self, self.hide);
end

function Lua_ChaosForestFightWinWindow:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:clearRewardList();
	self:superCall("dispose");
end

function Lua_ChaosForestFightWinWindow:showWin(param)
	self:superCall("showWin", param);

	if param.is_new_hurt == 1 then
		self.titleName:setAltas("chaos_forest_altas", "ui_hdsl_title_05");
	else
		self.titleName:setAltas("chaos_forest_altas", "ui_hdsl_title_04");
	end

	self:updateShowInfo();
end

function Lua_ChaosForestFightWinWindow:updateShowInfo()
	local hurt = self.showData.hurt_collect;
	local list = hurt.hurt_collect_list;
	if list == nil then
		return;
	end

	local idx = -1;
	local maxRot = -1;
	for i = 1, #list do
		if list[i].rotation > maxRot then
			maxRot = list[i].rotation;
			idx = i;
		end
	end

	local attackList = list[idx].attacker_hurt_collect;
	local defendList = list[idx].defender_hurt_collect;

	-- local mvpHeroId;
	local bossHurt;
	if hurt.attacker ~= nil and DataCenter.roleData:isMyself(hurt.attacker.id) == true then
		-- mvpHeroId = self:getMvpHeroId(attackList);
		bossHurt = self:getBossHurt(defendList);
	else
		-- mvpHeroId = self:getMvpHeroId(defendList);
		bossHurt = self:getBossHurt(attackList);
	end

	local index, maxHurt, prevHurt, isFinally = DataCenter.chaosForestUtil:getMaxHurt(bossHurt);
	self.stepText.text = "X"..index;
	self.hurtBar:setMaxValue(maxHurt);
	self.hurtBar:setValue(bossHurt);
	self.hurtBar:setText(bossHurt.."/"..maxHurt);

	local high_hurt = DataCenter.chaosForestData.high_hurt;
	bossHurt = (high_hurt > bossHurt) and high_hurt or bossHurt;
	self:showRewards(bossHurt);
end

function Lua_ChaosForestFightWinWindow:getMvpHeroId(list)
	local mvpHeroId;
	if list ~= nil then
		local obj;
		local num;
		local maxIdx;
		local maxHurt = -1;
		for i = 1, #list do
			obj = list[i];
			num = Mathf.Abs(tonumber(obj.hurt)) + Mathf.Abs(tonumber(obj.cure)) + Mathf.Abs(tonumber(obj.bear_hurt));
			if maxHurt < num then
				maxHurt = num;
				maxIdx = i;
			end
		end
		mvpHeroId = list[maxIdx].sort_id;
	end
	return mvpHeroId;
end

function Lua_ChaosForestFightWinWindow:getBossHurt(list)
	if list ~= nil then
		for i = 1, #list do
			if list[i].type == 5 then
				return tonumber(list[i].bear_hurt);
			end
		end
	end
	return 0;
end

function Lua_ChaosForestFightWinWindow:showRewards(bossHurt)
	local list = self.showData.item_list;
	if list == nil or #list <= 0 then
		-- 预览奖励
		local arr = DataCenter.chaosForestUtil:getHurtRewardArr();
		local config;
		local targetHurt;
		for i = 1, arr:getSize() do
			config = DataCenter.chaosForestUtil:getHurtRewardInfo(arr[i]);
			if bossHurt < config.hurt then
				targetHurt = config.hurt;
				list = config.reward;
				break;
			end
		end

		if list == nil or #list <= 0 then
			self.prompt_1:setLocation(-194, -261, 0);
			self.prompt_1.text = LanUtil.formateStr(340027, tostring(bossHurt));

			self.prompt_2:setLocation(-194, -310, 0);
			self.prompt_2:setLangValue(340029);
		else
			self.prompt_1:setLocation(-153.5, -261, 0);
			self.prompt_1.text = LanUtil.formateStr(340027, tostring(bossHurt));

			self.prompt_2:setLocation(-153.5, -310, 0);
			self.prompt_2.text = LanUtil.formateStr(340028, tostring(targetHurt));

			if self.itemIcon == nil then
				self.itemIcon = Lua_ItemIcon.new(self.content);
				self.itemIcon:setLocation(-227.5, -286, 0);
				self.itemIcon:setCanClick(true);
				
				local tvo = Lua_ToolVo.createToolVo(list[1][1], list[1][2]);
				self.itemIcon:setData(tvo);
				self.itemIcon:showGetLogo(true);
			end
		end
	else
		self.prompt_1.text = "";
		self.prompt_2.text = "";
		self:updateRewards(list);
	end
end

function Lua_ChaosForestFightWinWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self:clearRewardList();
		return;
	end

	local tab = DataCenter.packData:getRewardDic(itemList);
	local arr = DataCenter.packData:getRewardList(tab);
	if self.rewardList == nil then
		local len = arr:getSize();
		if len > 4 then
			self.rewardList = Lua_DragList.new(self.content, 608, 152, Lua_AxisDefine.Horizontal);
		else
			self.rewardList = Lua_DragList.new(self.content, len * 135, 152, Lua_AxisDefine.Horizontal);
		end
		self.rewardList:setLocation(0, -300, 0);
		self.rewardList:setListCell(Lua_FightResultRewardItem, 135, 152, 1);
	end
	self.rewardList:setArrayData(arr);
	self.rewardList.canDrag = not self.rewardList.bDragEnd;
end

function Lua_ChaosForestFightWinWindow:clearRewardList()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_ChaosForestFightWinWindow:onBtnBackClick(go)
	DataCenter.funcPathUtil:gotoFunction(1036, true, false);
end